@@ -5,30 +5,49 @@ package Template::Reverse::Spacer::HTML;
 use Any::Moose;
 use namespace::autoclean;
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 sub Space{
     my $self = shift;
     my $str = shift;
+	$str = _recover_url($str);
     my $spaced = _space($str);
 	return $spaced;
 }
 
+sub _recover_url{
+	my $str = shift;
+	$str=~s/(href=['"])([^'"]+)(['"])/$1._removeSpace($2).$3/ge;
+	$str=~s/(src=['"])([^'"]+)(['"])/$1._removeSpace($2).$3/ge;
+	$str=~s/^(https?:\/\/[^'"]+)$/_removeSpace($1)/ge;
+	return $str;
+}
+sub _removeSpace{
+	my $str = shift;
+	$str =~ s/\s+//g;
+	return $str;
+}
 
 sub _space{
     my $str = shift;
 	
 	# around html 
-	$str =~ s/<.+?>/ $& /g;
+	$str =~ s/<.+?>/ _tag_space($&) /ge;
 	# around attr
-	$str =~ s/=\s*(["']?)([^>\1]+)\1/=$1 $2 $1/g;
 
     $str =~ s/\s+/ /g;
-    $str =~ s/^\s//g;
-    $str =~ s/\s$//g;
+    $str =~ s/^\s+//g;
+    $str =~ s/\s+$//g;
     return $str;
 }
 
+sub _tag_space{
+	my $str = shift;
+
+	$str =~ s/=\s*(["']?)([^\1>]+)\1/=$1 $2 $1/g;
+	return " $str ";
+}
+
 
 __PACKAGE__->meta->make_immutable;
 1;
@@ -43,7 +62,7 @@ Template::Reverse::Spacer::HTML - Insert spaces around html tags and attrs
 
 =head1 VERSION
 
-version 0.02
+version 0.04
 
 =head1 SYNOPSIS
 
